Preferences/ProgramsDialog.py

branch
conda
changeset 6672
2af01e538c57
parent 6667
d45c9b0c3851
child 6782
390a45748883
diff -r 8baaf3bce895 -r 2af01e538c57 Preferences/ProgramsDialog.py
--- a/Preferences/ProgramsDialog.py	Sat Jan 26 17:04:11 2019 +0100
+++ b/Preferences/ProgramsDialog.py	Sat Jan 26 19:42:53 2019 +0100
@@ -215,8 +215,17 @@
             Utilities.isWindowsPlatform() and "rbrcc.exe" or "rbrcc",
             '-version', 'Ruby Resource Compiler', -1)
         
-        # 5. do the CORBA and Protobuf programs
-        # 5a. omniORB
+        # 5. do the Conda program(s)
+        exe = Preferences.getConda("CondaExecutable")
+        if not exe:
+            exe = "conda"
+            if Utilities.isWindowsPlatform():
+                exe += ".exe"
+        self.__createProgramEntry(
+            self.tr("conda Manager"), exe, '--version', 'conda', -1)
+        
+        # 6. do the CORBA and Protobuf programs
+        # 6a. omniORB
         exe = Preferences.getCorba("omniidl")
         if not exe:
             exe = "omniidl"
@@ -224,7 +233,7 @@
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("CORBA IDL Compiler"), exe, '-V', 'omniidl', -1)
-        # 5b. protobuf
+        # 6b. protobuf
         exe = Preferences.getProtobuf("protoc")
         if not exe:
             exe = "protoc"
@@ -232,7 +241,7 @@
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("Protobuf Compiler"), exe, '--version', 'libprotoc', -1)
-        # 5c. grpc
+        # 6c. grpc
         exe = Preferences.getProtobuf("grpcPython")
         if not exe:
             exe = sys.executable
@@ -240,7 +249,7 @@
             self.tr("gRPC Compiler"), exe, '--version', 'libprotoc', -1,
             exeModule=['-m', 'grpc_tools.protoc'])
         
-        # 6. do the spell checking entry
+        # 7. do the spell checking entry
         try:
             import enchant
             try:
@@ -257,7 +266,7 @@
         self.__createEntry(
             self.tr("Spell Checker - PyEnchant"), text, version)
         
-        # 7. do the pygments entry
+        # 8. do the pygments entry
         try:
             import pygments
             try:
@@ -274,7 +283,7 @@
         self.__createEntry(
             self.tr("Source Highlighter - Pygments"), text, version)
         
-        # do the plugin related programs
+        # 9. do the plugin related programs
         pm = e5App().getObject("PluginManager")
         for info in pm.getPluginExeDisplayData():
             if info["programEntry"]:

eric ide

mercurial